VerifyResponse class

Response returned by a facilitator when verifying a payment.

Constructors

VerifyResponse({required bool isValid, String? invalidReason, String? payer, Map<String, dynamic>? extensions})
const
VerifyResponse.fromJson(Map<String, dynamic> json)
factory

Properties

extensions → Map<String, dynamic>?
Optional facilitator-specific extensions.
final
hashCode → int
The hash code for this object.
no setterinherited
invalidReason → String?
Reason for invalidation, if any.
final
isValid → bool
Whether the payment is valid.
final
payer → String?
Address or identifier of the payer, if known.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited